OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Неуспешен опит за запис в \"config\" папката!",
    "This can usually be fixed by giving the web server write access to the config directory." : "Това обикновено може да бъде оправено като, се даде достъп на уеб сървъра да записва в config директорията.",
    "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "Но ако предпочитате да запазите файла config.php само за четене, задайте опцията \"config_is_read_only\" на true/вярно/ в него.",
    "See %s" : "Вижте %s",
    "Sample configuration detected" : "Открита е примерна конфигурация",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Усетено беше че примерната конфигурация е копирана. Това може да развли инсталацията ти и не се поддържа. Моля, прочети документацията преди да правиш промени на config.php",
    "The page could not be found on the server." : "Страницата не е намерена на сървъра.",
    "%s email verification" : "%s имейл потвърждение",
    "Email verification" : "Имейл потвърждение",
    "Click the following button to confirm your email." : "Щракнете върху следния бутон, за да потвърдите имейла си.",
    "Click the following link to confirm your email." : "Щракнете върху следната връзка, за да потвърдите имейла си.",
    "Confirm your email" : "Потвърдете имейла си",
    "Other activities" : "Други активности ",
    "%1$s and %2$s" : "%1$s и %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s и %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s и %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s и %5$s",
    "Enterprise bundle" : "Професионален пакет",
    "Groupware bundle" : "Софтуерен групов пакет",
    "Hub bundle" : "Хъб пакет",
    "Social sharing bundle" : "Пакет за социално споделяне",
    "PHP %s or higher is required." : "Изисква се PHP %s или по-нова.",
    "PHP with a version lower than %s is required." : "Необходим е PHP с версия по-ниска от %s.",
    "%sbit or higher PHP required." : "Нужно е %s бита или по-висок PHP.",
    "The following architectures are supported: %s" : "Поддържани са следните архитектури: %s",
    "The following databases are supported: %s" : "Поддържани са следните бази данни: %s",
    "The command line tool %s could not be found" : "Конзолната команда %s не може да бъде намерена",
    "The library %s is not available." : "Библиотеката %s не е налична",
    "Library %1$s with a version higher than %2$s is required - available version %3$s." : "Нужна е библиотека %1$s с версия, по-висока от %2$s – налична версия %3$s.",
    "Library %1$s with a version lower than %2$s is required - available version %3$s." : "Нужна е библиотека %1$s с версия, по-ниска от %2$s – налична версия %3$s.",
    "The following platforms are supported: %s" : "Поддържани са следните платформи: %s",
    "Server version %s or higher is required." : "Нужна е версия на сървъра %s или по-нова.",
    "Server version %s or lower is required." : "Нужна е версия на сървъра %s или по-ниска.",
    "Wiping of device %s has started" : "Започна изтриването на устройството %s",
    "Wiping of device »%s« has started" : "»%s« Започна изтриването на устройството ",
    "»%s« started remote wipe" : "»%s« започна отдалечено изтриване",
    "Device or application »%s« has started the remote wipe process. You will receive another email once the process has finished" : "Устройство или приложение »%s« стартира процеса на отдалечено изтриване. Ще получите друг имейл, след като процесът приключи ",
    "Wiping of device %s has finished" : "Изтриването на устройството %s завърши",
    "Wiping of device »%s« has finished" : "Изтриването на устройството »%s« завърши",
    "»%s« finished remote wipe" : "»%s« завърши отдалеченото изтриване",
    "Device or application »%s« has finished the remote wipe process." : "Устройство или приложение »%s« завърши процеса на отдалечено изтриване. ",
    "Remote wipe started" : "Започна отдалечено изтриване",
    "A remote wipe was started on device %s" : "Започна отдалечено изтриване на устройство %s",
    "Remote wipe finished" : "Отдалеченото изтриване завърши",
    "The remote wipe on %s has finished" : "Завърши %s на отдалеченото изтриване",
    "Authentication" : "Удостоверяване",
    "Unknown filetype" : "Непознат тип файл",
    "Invalid image" : "Невалидно изображение.",
    "Avatar image is not square" : "Изображението на аватара не е квадратно",
    "Files" : "Файлове",
    "View profile" : "Преглед на профил",
    "_%nh_::_%nh_" : ["%nч","%nч"],
    "Local time: %s" : "Местно време: %s",
    "today" : "днес",
    "tomorrow" : "утре",
    "yesterday" : "вчера",
    "_in %n day_::_in %n days_" : ["след %n дни","след %n дни"],
    "_%n day ago_::_%n days ago_" : ["преди %n ден","преди %n дни"],
    "next month" : "следващия месец",
    "last month" : "миналия месец",
    "_in %n month_::_in %n months_" : ["след %n месеца","след %n месеца"],
    "_%n month ago_::_%n months ago_" : ["преди %n месец","преди %n месеца"],
    "next year" : "следващата година",
    "last year" : "миналата година",
    "_in %n year_::_in %n years_" : ["след %n години","след %n "],
    "_%n year ago_::_%n years ago_" : ["преди %n година","преди %n години"],
    "_in %n hour_::_in %n hours_" : ["след %n часа","след "],
    "_%n hour ago_::_%n hours ago_" : ["преди %n час","преди %n часа"],
    "_in %n minute_::_in %n minutes_" : ["след %n минути","след "],
    "_%n minute ago_::_%n minutes ago_" : ["преди %n минута","преди %n минути"],
    "in a few seconds" : "след няколко секунди",
    "seconds ago" : "преди секунди",
    "Empty file" : "Празен файл",
    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Модул с ID: %s не съществува. Моля, активирайте го в настройките на приложенията си или се свържете с администратора си.",
    "Dot files are not allowed" : "Файлове с точки не са разрешени",
    "%1$s (renamed)" : "%1$s (преименуван)",
    "renamed file" : "преименуван файл",
    "Filenames must not end with \"%1$s\"." : "Имената на файловете не трябва да завършват с \"%1$s\"",
    "File already exists" : "Файлът вече съществува",
    "Invalid path" : "Невалиден път",
    "Failed to create file from template" : "Неуспешно създаване на файл от шаблон",
    "Templates" : "Шаблони",
    "Filename contains at least one invalid character" : "Името на файла съдържа поне един невалиден символ",
    "Empty filename is not allowed" : "Празно име на файл не е разрешено.",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "Приложението „%s“ не може да бъде инсталирано, защото appinfo/информация за приложението/ файлът не може да бъде прочетен.",
    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "Приложението \"%s\" не може да бъде инсталирано, защото не е съвместимо с тази версия на сървъра.",
    "__language_name__" : "Български",
    "This is an automatically sent email, please do not reply." : "Имейлът е генериран автоматично, моля не отговаряйте.",
    "Appearance and accessibility" : "Изглед и достъпност",
    "Apps" : "Приложения",
    "Personal settings" : "Лични настройки",
    "Administration settings" : "Административни настройки",
    "Settings" : "Настройки",
    "Log out" : "Отписване",
    "Accounts" : "Профили",
    "Bluesky" : "Bluesky",
    "Email" : "Имейл",
    "Mail %s" : "Поща %s",
    "Fediverse" : "Fediverse /съвкупност от обединени сървъри/",
    "View %s on the fediverse" : "Преглед на %s във Fediverse",
    "Phone" : "Телефон",
    "Call %s" : "Обаждане %s",
    "Twitter" : "Twitter",
    "View %s on Twitter" : "Изглед %s в Twitter",
    "Website" : "Уеб сайт",
    "Visit %s" : "Посещение %s",
    "Address" : "Адрес",
    "Profile picture" : "Профилна снимка",
    "About" : "Относно",
    "Display name" : "Име за визуализация",
    "Headline" : "Заглавие",
    "Organization" : "Организиране",
    "Role" : "Роля",
    "Pronouns" : "Обръщение",
    "Additional settings" : "Допълнителни настройки",
    "Enter the database name for %s" : "Въведете името на базата данни за %s",
    "You cannot use dots in the database name %s" : "Не можете да използвате точки в името на базата данни %s",
    "You need to enter details of an existing account." : "Трябва да въведете подробности за съществуващ профил.",
    "Oracle connection could not be established" : "Не можа да се установи връзка с Oracle",
    "For the best results, please consider using a GNU/Linux server instead." : "За най-добри резултати, моля, помисли дали не бихте желали да използваште GNU/Linux сървър.",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : " Изглежда, че този екземпляр %s работи в 32-битова PHP среда и open_basedir е конфигуриран в php.ini. Това ще доведе до проблеми с файлове над 4 GB и е силно обезкуражено.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Моля, премахтене настройката за open_basedir от вашия php.ini или преминете към 64-битово PHP.",
    "Set an admin password." : "Задай парола за администратор.",
    "Cannot create or write into the data directory %s" : "Неуспешно създаване или записване в директорията  с данни \"data\" %s",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Споделянето на сървърния %s трябва да поддържа OCP\\Share_Backend интерфейс.",
    "Sharing backend %s not found" : "Споделянето на сървърния %s не е открито.",
    "Sharing backend for %s not found" : "Споделянето на сървъра за %s не е открито.",
    "%1$s via %2$s" : "%1$s чрез %2$s",
    "Unknown share type" : "Неизвестен тип споделяне",
    "You are not allowed to share %s" : "Не ти е разрешено да споделяш %s.",
    "Cannot increase permissions of %s" : "Не могат да се увеличат права на %s",
    "Files cannot be shared with delete permissions" : "Файловете не могат да се споделят с права за изтриване",
    "Files cannot be shared with create permissions" : "Файловете не могат да се споделят с права за създаване",
    "Expiration date is in the past" : "Срокът на валидност е изтекъл",
    "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Не може да се зададе срок на валидност повече от %n дни в бъдещето","Не може да се зададе срок на валидност повече от %n дни в бъдещето"],
    "Sharing is only allowed with group members" : "Споделянето е разрешено само с членове на групата",
    "The requested share does not exist anymore" : "Исканото споделяне вече не съществува",
    "The user was not created because the user limit has been reached. Check your notifications to learn more." : "Потребителят не е създаден, тъй като е достигнат лимитът на потребителите. Проверете вашите известия, за да научите повече.",
    "Could not find category \"%s\"" : "Невъзможно откриване на категорията \"%s\".",
    "Sunday" : "неделя",
    "Monday" : "понеделник",
    "Tuesday" : "вторник",
    "Wednesday" : "сряда",
    "Thursday" : "четвъртък",
    "Friday" : "петък",
    "Saturday" : "събота",
    "Sun." : "нед",
    "Mon." : "пон",
    "Tue." : "вт",
    "Wed." : "ср",
    "Thu." : "чет",
    "Fri." : "пет",
    "Sat." : "съб",
    "Su" : "нд",
    "Mo" : "пн",
    "Tu" : "вт",
    "We" : "ср",
    "Th" : "чт",
    "Fr" : "пт",
    "Sa" : "сб",
    "January" : "януари",
    "February" : "февруару",
    "March" : "март",
    "April" : "април",
    "May" : "май",
    "June" : "юни",
    "July" : "юли",
    "August" : "август",
    "September" : "септември",
    "October" : "октомври",
    "November" : "ноември",
    "December" : "декември",
    "Jan." : "яну",
    "Feb." : "фев",
    "Mar." : "мар",
    "Apr." : "апр",
    "May." : "май",
    "Jun." : "юни",
    "Jul." : "юли",
    "Aug." : "авг",
    "Sep." : "сеп",
    "Oct." : "окт",
    "Nov." : "ное",
    "Dec." : "дек",
    "A valid password must be provided" : "Трябва да въведете валидна парола.",
    "Login canceled by app" : "Вписването е отказано от приложението",
    "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "Приложението „%1$s“ не може да бъде инсталирано, защото следните зависимости не са изпълнени: %2$s",
    "a safe home for all your data" : "безопасен дом за всички ваши данни",
    "Application is not enabled" : "Приложението не е включено",
    "Authentication error" : "Грешка при удостоверяването",
    "Token expired. Please reload page." : "Изтекла сесия. Моля, презареди страницата.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Липсват инсталирани драйвери за бази данни(sqlite, mysql или postgresql).",
    "Cannot write into \"config\" directory." : "Не може да се пише в \"config\" директория.",
    "This can usually be fixed by giving the web server write access to the config directory. See %s" : "Това обикновено може да бъде оправено като, се даде достъп на уеб сървъра да записва в config директорията. Погледнете %s",
    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Но ако предпочитате да запазите файла config.php само за четене, задайте опцията \"config_is_read_only\" на true/вярно/ в него. Погледнете %s",
    "Cannot create \"data\" directory." : "Неможе да се създаде \"data\" директория с данни.",
    "This can usually be fixed by giving the web server write access to the root directory. See %s" : "Това обикновено може да бъде оправено като, се даде достъп на уеб сървъра да записва в основната директория. Погледнете %s",
    "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "Права обикновено могат да бъдат оправени когато се даде достъп на уеб сървъра да пише в основната директория. Погледнете %s.",
    "Your data directory is not writable." : "Вашата директория с данни не е записваема.",
    "Setting locale to %s failed." : "Неуспешно задаване на регион %s. ",
    "Please install one of these locales on your system and restart your web server." : "Моля, задайте един от следните региони във Вашата система след което рестартирайте сървъра.",
    "PHP module %s not installed." : "PHP модулът %s не е инсталиран.",
    "Please ask your server administrator to install the module." : "Моля, помолете вашия администратор да инсталира модула.",
    "PHP setting \"%s\" is not set to \"%s\"." : "PHP настройка \"%s\" не е зададена на \"%s\".",
    "Adjusting this setting in php.ini will make Nextcloud run again" : "Регулирането на тази настройка в php.ini ще накара Nextcloud да работи отново",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP е настроен да премахва inline doc блокове. Това ще направи няколко основни приложения недостъпни.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Това може да се дължи на cache/accelerator като Zend OPache или eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "PHP модулите са инсталирани, но все още се обявяват като липсващи?",
    "Please ask your server administrator to restart the web server." : "Моля, поискай от своя администратор да рестартира уеб сървъра.",
    "The required %s config variable is not configured in the config.php file." : "Необходимата %s конфигурационна променлива не е конфигурирана във файла config.php.",
    "Please ask your server administrator to check the Nextcloud configuration." : "Моля, помолете администратора на вашия сървър да провери конфигурацията на Nextcloud.",
    "Your data directory must be an absolute path." : "Вашата директория с данни трябва да е абсолютен път.",
    "Check the value of \"datadirectory\" in your configuration." : "Проверете стойността на \"datadirectory\" във вашата конфигурация.",
    "Your data directory is invalid." : "Вашата директория с данни е невалидна.",
    "Action \"%s\" not supported or implemented." : "Действието „%s“ не се поддържа или изпълнява.",
    "Authentication failed, wrong token or provider ID given" : "Неуспешно удостоверяване, даден е грешен токен или идентификатор на доставчика ",
    "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "Липсват параметри, за завършване на заявката. Липсващи параметри: \"%s\"",
    "ID \"%1$s\" already used by cloud federation provider \"%2$s\"" : "Идентификатор „%1$s“ вече се използва от доставчика на облачно федериране „%2$s“",
    "Cloud Federation Provider with ID: \"%s\" does not exist." : "Доставчик на облачна федерация с ID: „%s“ не съществува.",
    "Could not obtain lock type %d on \"%s\"." : "Неуспешен опит за ексклузивен достъп от типa %d върху \"%s\".",
    "Storage unauthorized. %s" : "Неупълномощено хранилище. %s",
    "Storage incomplete configuration. %s" : "Непълна конфигурация на хранилище. %s",
    "Storage connection error. %s" : "Грешка при свързването с хранилище. %s",
    "Storage is temporarily not available" : "Временно хранилището не е налично",
    "Storage connection timeout. %s" : "Време за изчакване при свързването с хранилище. %s",
    "Images" : "Изображения",
    "Question" : "Въпрос",
    "Confirmation" : "Потвърждение",
    "Optical character recognition" : "Оптично разпознаване на символи",
    "Prompt" : "Подкана",
    "Text" : "Текст",
    "Summary" : "Резюме",
    "Translate" : "Превод",
    "Target language" : "Целеви език",
    "Result" : "Резултат",
    "Organisation" : "Организация",
    "Cannot write into \"apps\" directory." : "Не може да се пише в \"apps\" директория.",
    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Това обикновено може да бъде оправено като се даде достъп на уеб сървъра да записва в app директорията или като изключи приложението магазин за приложения в config файла.",
    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> е настроен на <code>%s</code> вместо очакваната стойност <code>0</code>.",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "За оправяне на този проблем, задайте <code>mbstring.func_overload</code> на <code>0</code> във вашият php.ini."
},
"nplurals=2; plural=(n != 1);");
